@@ -331,6 +331,7 @@ class Player(GObject.GObject):
         return media
 
     def load(self, media):
+        self.progressScale.set_value(0)
         self._set_duration(media.get_duration())
         self.songTotalTimeLabel.set_label(self.seconds_to_string(media.get_duration()))
         self.progressScale.set_sensitive(True)
@@ -542,7 +543,7 @@ class Player(GObject.GObject):
 
     def _update_position_callback(self):
         position = self.player.query_position(Gst.Format.TIME)[1] / 1000000000
-        if position >= 0:
+        if position > 0:
             self.progressScale.set_value(position * 60)
         return True
 
